pub struct MatrixConfig {
pub home_server: String,
pub next_batch: Option<String>,
pub txn_id: u64,
pub login: Value,
}Expand description
The “matrix” section of the config, which gives home server, login information, and etc.
Fields
home_server: StringYour homeserver of choice, as an FQDN without scheme or path
next_batch: Option<String>The next batch to grab. This should be set automatically
txn_id: u64The transaction ID. This should be set automatically
login: ValueThe login table. This may be set to whatever you wish, depending on your login method, though multi-step logins (like challenge-based) won’t work here.