pub fn parse_command(s: &str) -> Result<Option<Box<dyn Command>>, String>Expand description
Parse a command string into a dynamic command execution trait object. Returns an error if a command was recognized but not parsed correctly. Returns None if no command was recognized.