pub fn parse_command(
original_input: &str,
) -> IResult<&str, Option<Box<dyn Command>>>Expand description
Potentially parse a command expression. If we recognize the command, an error should be raised if the command is misparsed. If we don’t recognize the command, ignore it and return none